# eric7.WebBrowser.WebAuth

Package implementing dialogs for the WebAuth flow and security key management.

### Modules

Fido2InfoDialog | Module implementing a dialog showing information about the selected security key.
Fido2Management | Module implementing a manager for FIDO2 security keys.
Fido2ManagementDialog | Module implementing a dialog to manage FIDO2 security keys.
Fido2PasskeyEditDialog | Module implementing a dialog for editing passkey parameters.
Fido2PinDialog | Module implementing a dialog to enter the current and potentially new PIN.
WebBrowserWebAuthDialog | Module implementing a dialog to handle the various WebAuth requests.